"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userFlowReportToMdTable = void 0;
const prettier_1 = require("../../../core/prettier");
const generate_reports_1 = require("../../collect/processes/generate-reports");
/**
 * | Step Name       | Gather Mode |Performance | Accessibility | BestPractices | Seo  | PWA |
 * | --------------- | ----------- | ------------- | ------------- | ---- | --- |
 * |  Nav1           |  99         | 50            | 100           | 98   |  -  |
 * |  Snap   1       |  3/3        | 22/5          | 5/2           | 7/10 |  -  |
 * |  TimeSpan 1     |  10/11      | -             | 4/7           | 7/10 |  -  |
 */
function userFlowReportToMdTable(flowResult, baselineResults) {
    const reducedReport = (0, generate_reports_1.createReducedReport)(flowResult);
    const reportCategories = Object.keys(reducedReport.steps[0].results);
    const tableStepsArr = formatStepsForMdTable(reportCategories, reducedReport, baselineResults);
    const alignOptions = generateTableAlignOptions(reportCategories);
    const tableArr = extractTableArr(reportCategories, tableStepsArr);
    return markdownTable(tableArr, alignOptions);
}
exports.userFlowReportToMdTable = userFlowReportToMdTable;
function formatStepsForMdTable(reportCategories, reducedReport, baselineResults) {
    if (baselineResults) {
        const enrichedReducedReport = (0, generate_reports_1.enrichReducedReportWithBaseline)(reducedReport, baselineResults);
        return enrichedReducedReport.steps.map((step) => {
            const results = reportCategories.map(category => extractEnrichedResults(step, category));
            return [step.name, step.gatherMode].concat(results);
        });
    }
    return reducedReport.steps.map((step) => {
        const results = reportCategories.map(category => extractResultsValue(step.results[category]));
        return [step.name, step.gatherMode].concat(results);
    });
}
const alignString = new Map([['l', ':--'], ['c', ':--:'], ['r', '--:']]);
function markdownTable(data, align) {
    const _data = data.map((arr) => arr.join('|'));
    const secondRow = align.map((s) => alignString.get(s)).join('|');
    return (0, prettier_1.formatCode)(_data.shift() + '\n' + secondRow + '\n' + _data.join('\n'), 'markdown');
}
function extractTableArr(reportCategories, steps) {
    const tableHead = extractTableHead(reportCategories);
    return [tableHead].concat(steps);
}
function extractTableHead(reportCategories) {
    return ['Step Name', 'Gather Mode']
        .concat(reportCategories.map(c => c.split('-').map(cN => cN[0].toUpperCase() + cN.slice(1)).join(' ')));
}
function extractFractionalResultValue(fractionResults) {
    const { totalWeight, numPassed, numPassableAudits } = fractionResults;
    const value = numPassed + '/' + numPassableAudits;
    return totalWeight === 0 ? 'Ø ' + value : value;
}
function extractResultsValue(stepResult) {
    if (typeof stepResult === 'number') {
        return (stepResult * 100).toFixed(0);
    }
    return stepResult ? extractFractionalResultValue(stepResult) : '-';
}
function extractEnrichedResults(step, category) {
    const result = extractResultsValue(step.results[category]);
    const baseline = extractResultsValue(step.baseline[category]);
    return resultWithBaselineComparison(result, baseline);
}
function resultWithBaselineComparison(result, baseline) {
    if (result === baseline) {
        return result;
    }
    const resultNum = Number(result.replace('Ø ', '').split('/')[0]);
    const baselineNum = Number(baseline.replace('Ø ', '').split('/')[0]);
    const difference = baselineNum - resultNum;
    return `${result} (${difference > 0 ? '+' : ''}${difference})`;
}
function generateTableAlignOptions(reportCategories) {
    const reportFormats = reportCategories.map(_ => 'c');
    return ['l', 'c'].concat(reportFormats);
}
//# sourceMappingURL=md-table.js.map